Selects a subspace closest to a given variable. To select the subspace, the method considers (for every subspace) a subset of its principal components and tries to fit a linear model with the variable as the response. Then the method chooses the subspace for which the value of BIC was the highest.
choose.cluster.BIC(variable, pcas, number.clusters,
show.warnings = FALSE)A variable to be assigned.
Orthogonal basis for each of the subspaces.
Number of subspaces (clusters).
A boolean - if set to TRUE all warnings are displayed, default value is FALSE.
index Number of most similar subspace to variable.